@@ -13,7 +13,7 @@ from ...covariance import CovarianceModel
 from ...decomposition import CovarianceKoopmanModel, vamp_score
 from .._pcca import pcca, PCCAModel
 from .._reactive_flux import ReactiveFlux
-from .._sample import ensure_dtraj_list, compute_index_states
+from ..sample import ensure_dtraj_list, compute_index_states
 from ..tools import analysis as msmana
 from .._transition_counting import TransitionCountModel
 from .._util import count_states
@@ -121,10 +121,62 @@ class MarkovStateModel(Model):
 
     @cached_property
     def koopman_model(self) -> CovarianceKoopmanModel:
+        r"""Yields a :class:`CovarianceKoopmanModel` based on the transition matrix and stationary
+         distribution of this Markov state model.
+
+        Returns
+        -------
+        model : CovarianceKoopmanModel
+            The model.
+
+        Notes
+        -----
+        If :math:`P\in\mathbb{R}^{n\times n}` denotes the transition matrix and :math:`\mu\in\mathbb{R}^n` denotes
+        the stationary distribution, we define covariance matrices
+
+        .. math::
+            \begin{aligned}
+            C_{00} &= C_{11} = \text{diag} (\mu_1,\ldots,\mu_n)\\
+            C_{01} &= C_{00}P
+            \end{aligned}
+
+        and based on these a Koopman operator :math:`K = C_{00}^{-1/2}C_{01}C_{11}^{-1/2}`.
+
+        See Also
+        --------
+        to_koopman_model
+        """
         return self.to_koopman_model(False)
 
     @cached_property
     def empirical_koopman_model(self) -> CovarianceKoopmanModel:
+        r"""Yields a :class:`CovarianceKoopmanModel` based on the count matrix of this Markov state model.
+
+        Returns
+        -------
+        model : CovarianceKoopmanModel
+            The model.
+
+        Notes
+        -----
+        If :math:`C\in\mathbb{R}^{n\times n}` denotes the count matrix and :math:`P` the transition matrix,
+        we define covariance matrices based on transition count statistics
+
+        .. math::
+
+            \begin{aligned}
+            C_{00} &= \text{diag} \left( \sum_i C_{i1}, \ldots, \sum_i C_{in} \right) \\
+            C_{11} &= \text{diag} \left( \sum_i C_{1i}, \ldots, \sum_i C_{ni} \right) \\
+            C_{01} &= C,
+            \end{aligned}
+
+        and reweight the operator :math:`P` to the empirical distribution via :math:`C_{01\text{, re}} = C_{00}P`.
+        Based on these we define the Koopman operator :math:`K = C_{00}^{-1/2}C_{01\text{, re}}C_{11}^{-1/2}`.
+
+        See Also
+        --------
+        to_koopman_model
+        """
         return self.to_koopman_model(True)
 
     def to_koopman_model(self, empirical: bool = True, epsilon: float = 1e-10):
@@ -216,20 +268,21 @@ class MarkovStateModel(Model):
         """ Number of Lanczos vectors used when computing the partial eigenvalue decomposition """
         return self._ncv
 
-    def submodel(self, states: np.ndarray):
+    def submodel(self, states):
         r"""
         Restricts this markov state model to a subset of states by taking a submatrix of the transition matrix
         and re-normalizing it, as well as restricting the stationary distribution and count model if given.
 
         Parameters
         ----------
-        states : ndarray(m, dtype=int)
+        states : array_like of int
             states to restrict to
         Returns
         -------
         submodel : MarkovStateModel
             A onto the given states restricted MSM.
         """
+        states = np.asarray(states)
         if np.any(states >= self.n_states):
             raise ValueError("At least one of the given states is not contained in this model "
                              "(n_states={}, max. given state={}).".format(self.n_states, np.max(states)))
@@ -440,7 +493,7 @@ class MarkovStateModel(Model):
             self._ensure_eigenvalues()
         else:
             self._ensure_eigenvalues(neig=k + 1)
-        from deeptime.markov.tools.analysis.dense._decomposition import timescales_from_eigenvalues as timescales
+        from deeptime.markov.tools.analysis import timescales_from_eigenvalues as timescales
 
         ts = timescales(self._eigenvalues, tau=self.lagtime)
         if k is None:
@@ -522,7 +575,7 @@ class MarkovStateModel(Model):
         from deeptime.markov.tools.analysis import mfpt
         self._assert_in_active(A)
         self._assert_in_active(B)
-        return self.lagtime * mfpt(self.transition_matrix, B, origin=A, mu=self.stationary_distribution)
+        return mfpt(self.transition_matrix, B, tau=self.lagtime, origin=A, mu=self.stationary_distribution)
 
     def committor_forward(self, A, B):
         """Forward committor (also known as p_fold or splitting probability) from set A to set B.
